[−][src]Enum context_allocator::global::CurrentAllocatorInUse
Records which allocator is currently in use for Global allocations.
This does not affect reallocations or deallocations in any way.
Variants
CoroutineLocalA coroutine local allocator.
ThreadLocalA thread local allocator.
GlobalA global allocator.