[−][src]Enum context_allocator::mmap::HugePageSize
Request that an allocation uses huge pages.
The allocation being requested has to be aligned to the size requested, viz it is best to only make allocations that use the configured huge page size.
On x86-64, this should be 2Mb or 1Gb.
Currently such requests assume that transparent huge pages are in effect.
On operating systems other than Android and Linux, huge page size has no effect.
Variants
NoneRegular, non-huge-page.
DefaultEquivalent to MAP_HUGETLB.
_64KbEquivalent to MAP_HUGETLB | MAP_HUGE_64KB.
Suitable for ?
_512KbEquivalent to MAP_HUGETLB | MAP_HUGE_512KB.
Suitable for ?
_1MbEquivalent to MAP_HUGETLB | MAP_HUGE_1Mb.
Suitable for ?
_2MbEquivalent to MAP_HUGETLB | MAP_HUGE_2MB.
Suitable for x86-64.
_8MbEquivalent to MAP_HUGETLB | MAP_HUGE_8MB.
Suitable for ?
_16MbEquivalent to MAP_HUGETLB | MAP_HUGE_16MB.
Suitable for ?
_32MbEquivalent to MAP_HUGETLB | MAP_HUGE_32MB.
Suitable for ?
_256MbEquivalent to MAP_HUGETLB | MAP_HUGE_256MB.
Suitable for ?
_512MbEquivalent to MAP_HUGETLB | MAP_HUGE_512MB.
Suitable for ?
_1GbEquivalent to MAP_HUGETLB | MAP_HUGE_1GB.
Suitable for x86-64.
_2GbEquivalent to MAP_HUGETLB | MAP_HUGE_2GB.
Suitable for ?
_16GbEquivalent to MAP_HUGETLB | MAP_HUGE_16GB.
Suitable for PowerPC.